@@ -8,8 +8,6 @@
 ( cd opt/kde/share/doc/HTML/sl/kfind ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/kpackage ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/quickstart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sl/khelpcenter/quickstart ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/sl/common common )
 ( cd opt/kde/share/doc/HTML/sl/khelpcenter/userguide ; rm -rf common )
